@@ -30,24 +30,24 @@ class GoogleBigQueryConnector(ToucanConnector):
         ...,
         title='Google Credentials',
         description='For authentication, download an authentication file from your '
-        '<a href="https://console.developers.google.com/apis/credentials">Google Console</a> and '
+        '<a href="https://console.developers.google.com/apis/credentials" target="_blank">Google Console</a> and '
         'use the values here. This is an oauth2 credential file. For more information see this '
-        '<a href="https://gspread.readthedocs.io/en/latest/oauth2.html">documentation</a>. '
+        '<a href="https://gspread.readthedocs.io/en/latest/oauth2.html" target="_blank" >documentation</a>. '
         'You should use "service_account" credentials, which is the preferred type of credentials '
         'to use when authenticating on behalf of a service or application',
     )
     dialect: Dialect = Field(
-        Dialect.legacy,
+        Dialect.standard,
         description='BigQuery allows you to choose between standard and legacy SQL as query syntax. '
         'The preferred query syntax is the default standard SQL. You can find more information on this '
-        '<a href="https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax">documentation</a>',
+        '<a href="https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax" target="_blank" >documentation</a>',
     )
     scopes: List[str] = Field(
         ['https://www.googleapis.com/auth/bigquery'],
         title='OAuth scopes',
         description='OAuth 2.0 scopes define the level of access you need to request '
         'the Google APIs. For more information, see this '
-        '<a href="https://developers.google.com/identity/protocols/googlescopes">documentation</a>',
+        '<a href="https://developers.google.com/identity/protocols/googlescopes" target="_blank" >documentation</a>',
     )
 
     def _retrieve_data(self, data_source: GoogleBigQueryDataSource) -> pd.DataFrame:
